summaryrefslogtreecommitdiffstats
path: root/src/jrummikub/view/IPlayerPanel.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/jrummikub/view/IPlayerPanel.java')
-rw-r--r--src/jrummikub/view/IPlayerPanel.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/jrummikub/view/IPlayerPanel.java b/src/jrummikub/view/IPlayerPanel.java
index f07ced4..dd24e33 100644
--- a/src/jrummikub/view/IPlayerPanel.java
+++ b/src/jrummikub/view/IPlayerPanel.java
@@ -28,20 +28,20 @@ public interface IPlayerPanel {
public void setTimeLeft(int time);
/**
* The sort by number event is emitted when the player wants to sort his
* stones by number
*
* @return the event
*/
- public IEvent getSortByNumberEvent();
+ public IEvent getSortByGroupsEvent();
/**
* The sort by number event is emitted when the player wants to sort his
* stones by number
*
* @return the event
*/
- public IEvent getSortByColorEvent();
+ public IEvent getSortByRunsEvent();
/**
* The end turn event is emitted when the player wants to end his turn
@@ -28,20 +28,20 @@ public interface IPlayerPanel {
public void setTimeLeft(int time);
/**
- * The sort by number event is emitted when the player wants to sort his
- * stones by number
+ * The sort by groups event is emitted when the player wants to sort his
+ * stones by groups
*
* @return the event
@@ -28,20 +28,20 @@ public interface IPlayerPanel {
/**
- * The sort by number event is emitted when the player wants to sort his
- * stones by number
+ * The sort by runs event is emitted when the player wants to sort his stones
+ * by runs
*
* @return the event